@@ -1,5 +1,5 @@
 # -*- test-case-name: twisted.test.test_application,twisted.test.test_twistd -*-
-# Copyright (c) 2001-2008 Twisted Matrix Laboratories.
+# Copyright (c) 2001-2010 Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 import sys, os, pdb, getpass, traceback, signal, warnings
@@ -174,11 +174,6 @@ class AppProfiler(object):
         saveStats = options.get("savestats", False)
         profileOutput = options.get("profile", None)
         self.profiler = options.get("profiler", "hotshot").lower()
-        if options.get("nothotshot", False):
-            warnings.warn("The --nothotshot option is deprecated. Please "
-                          "specify the profiler name using the --profiler "
-                          "option", category=DeprecationWarning)
-            self.profiler = "profile"
         if self.profiler in self.profilers:
             profiler = self.profilers[self.profiler](profileOutput, saveStats)
             self.run = profiler.run
@@ -187,32 +182,6 @@ class AppProfiler(object):
 
 
 
-def runWithProfiler(reactor, config):
-    """
-    DEPRECATED in Twisted 8.0.
-
-    Run reactor under standard profiler.
-    """
-    warnings.warn("runWithProfiler is deprecated since Twisted 8.0. "
-                  "Use ProfileRunner instead.", DeprecationWarning, 2)
-    item = AppProfiler(config)
-    return item.run(reactor)
-
-
-
-def runWithHotshot(reactor, config):
-    """
-    DEPRECATED in Twisted 8.0.
-
-    Run reactor under hotshot profiler.
-    """
-    warnings.warn("runWithHotshot is deprecated since Twisted 8.0. "
-                  "Use HotshotRunner instead.", DeprecationWarning, 2)
-    item = AppProfiler(config)
-    return item.run(reactor)
-
-
-
 class AppLogger(object):
     """
     Class managing logging faciliy of the application.
@@ -330,12 +299,6 @@ def runReactorWithLogging(config, oldstdout, oldstderr, profiler=None, reactor=N
         if config['profile']:
             if profiler is not None:
                 profiler.run(reactor)
-            else:
-                # Backward compatible code
-                if not config['nothotshot']:
-                    runWithHotshot(reactor, config)
-                else:
-                    runWithProfiler(reactor, config)
         elif config['debug']:
             sys.stdout = oldstdout
             sys.stderr = oldstderr
@@ -410,30 +373,12 @@ class ApplicationRunner(object):
         self.preApplication()
         self.application = self.createOrGetApplication()
 
-
-        getLogObserverLegacy = getattr(self, 'getLogObserver', None)
-        if getLogObserverLegacy is not None:
-            warnings.warn("Specifying a log observer with getLogObserver is "
-                          "deprecated. Please use a loggerFactory instead.",
-                          category=DeprecationWarning)
-            self.startLogging(self.getLogObserver())
-        else:
-            self.logger.start(self.application)
+        self.logger.start(self.application)
 
         self.postApplication()
         self.logger.stop()
 
 
-    def startLogging(self, observer):
-        """
-        Initialize the logging system. DEPRECATED.
-
-        @param observer: The observer to add to the logging system.
-        """
-        log.startLoggingWithObserver(observer)
-        self.logger._initialLog()
-
-
     def startReactor(self, reactor, oldstdout, oldstderr):
         """
         Run the reactor with the given configuration.  Subclasses should
@@ -523,15 +468,6 @@ Please read the 'Using Application' HOWTO for details.
 
 
 
-def reportProfile(report_profile, name):
-    """
-    DEPRECATED since Twisted 8.0. This does nothing.
-    """
-    warnings.warn("reportProfile is deprecated and a no-op since Twisted 8.0.",
-                  category=DeprecationWarning)
-
-
-
 def _reactorZshAction():
     return "(%s)" % " ".join([r.shortName for r in reactors.getReactorTypes()])
 
@@ -589,10 +525,7 @@ class ServerOptions(usage.Options, ReactorSelectionMixin):
                  "the profiler."],
                 ['no_save','o',   "do not save state on shutdown"],
                 ['encrypted', 'e',
-                 "The specified tap/aos file is encrypted."],
-                ['nothotshot', None,
-                 "DEPRECATED. Don't use the hotshot profiler even if "
-                 "it's available."]]
+                 "The specified tap/aos file is encrypted."]]
 
     optParameters = [['logfile','l', None,
                       "log to a specified file, - for stdout"],
@@ -708,6 +641,8 @@ def convertStyle(filein, typein, passphrase, fileout, typeout, encrypt):
         fileout = None
     sob.IPersistable(application).save(filename=fileout, passphrase=passphrase)
 
+
+
 def startApplication(application, save):
     from twisted.internet import reactor
     service.IService(application).startService()
@@ -717,14 +652,3 @@ def startApplication(application, save):
     reactor.addSystemEventTrigger('before', 'shutdown',
                                   service.IService(application).stopService)
 
-def getLogFile(logfilename):
-    """
-    Build a log file from the full path.
-    """
-    warnings.warn(
-        "app.getLogFile is deprecated. Use "
-        "twisted.python.logfile.LogFile.fromFullPath instead",
-        DeprecationWarning, stacklevel=2)
-
-    return logfile.LogFile.fromFullPath(logfilename)
-
