@@ -1,5 +1,5 @@
 # -*- test-case-name: twisted.trial.test.test_runner -*-
-# Copyright (c) 2001-2009 Twisted Matrix Laboratories.
+# Copyright (c) 2001-2010 Twisted Matrix Laboratories.
 # See LICENSE for details.
 
 """
@@ -14,7 +14,6 @@ import os, types, warnings, sys, inspect, imp
 import random, doctest, time
 
 from twisted.python import reflect, log, failure, modules, filepath
-from twisted.python.util import dsu
 from twisted.python.compat import set
 from twisted.python.lockfile import FilesystemLock
 
@@ -340,6 +339,8 @@ class TestHolder(object):
 
     implements(ITestCase)
 
+    failureException = None
+
     def __init__(self, description):
         """
         @param description: A string to be displayed L{TestResult}.
@@ -347,10 +348,30 @@ class TestHolder(object):
         self.description = description
 
 
+    def __call__(self, result):
+        return self.run(result)
+
+
     def id(self):
         return self.description
 
 
+    def countTestCases(self):
+        return 0
+
+
+    def run(self, result):
+        """
+        This test is just a placeholder. Run the test successfully.
+
+        @param result: The C{TestResult} to store the results in.
+        @type result: L{twisted.trial.itrial.ITestResult}.
+        """
+        result.startTest(self)
+        result.addSuccess(self)
+        result.stopTest(self)
+
+
     def shortDescription(self):
         return self.description
 
@@ -382,15 +403,15 @@ class ErrorHolder(TestHolder):
 
 
     def run(self, result):
-        result.addError(self, self.error)
+        """
+        Run the test, reporting the error.
 
-
-    def __call__(self, result):
-        return self.run(result)
-
-
-    def countTestCases(self):
-        return 0
+        @param result: The C{TestResult} to store the results in.
+        @type result: L{twisted.trial.itrial.ITestResult}.
+        """
+        result.startTest(self)
+        result.addError(self, util.excInfoOrFailureToExcInfo(self.error))
+        result.stopTest(self)
 
 
     def visit(self, visitor):
@@ -436,7 +457,7 @@ class TestLoader(object):
 
         @param xs: A list of test cases, class or modules.
         """
-        return dsu(xs, self.sorter)
+        return sorted(xs, key=self.sorter)
 
     def findTestClasses(self, module):
         """Given a module, return all Trial test classes"""
@@ -695,13 +716,13 @@ class TrialRunner(object):
             import readline
         except ImportError:
             print "readline module not available"
-            hasattr(sys, 'exc_clear') and sys.exc_clear()
+            sys.exc_clear()
         for path in ('.pdbrc', 'pdbrc'):
             if os.path.exists(path):
                 try:
                     rcFile = file(path, 'r')
                 except IOError:
-                    hasattr(sys, 'exc_clear') and sys.exc_clear()
+                    sys.exc_clear()
                 else:
                     dbg.rcLines.extend(rcFile.readlines())
         return dbg
@@ -711,8 +732,11 @@ class TrialRunner(object):
         """
         Safely remove a path, recursively.
 
-        If C{path} does not contain a node named C{_trial_marker}, a
-        L{_NoTrialmarker} exception is raised and the path is not removed.
+        If C{path} does not contain a node named C{"_trial_marker"}, a
+        L{_NoTrialMarker} exception is raised and the path is not removed.
+
+        @type path: L{twisted.python.filepath.FilePath}
+        @param path: The absolute path to a test directory
         """
         if not path.child('_trial_marker').exists():
             raise _NoTrialMarker(
@@ -725,12 +749,12 @@ class TrialRunner(object):
             print ("could not remove %r, caught OSError [Errno %s]: %s"
                    % (path, e.errno, e.strerror))
             try:
-                newPath = FilePath('_trial_temp_old%s'
-                                   % random.randint(0, 99999999))
+                newPath = filepath.FilePath('_trial_temp_old%s'
+                                            % random.randint(0, 99999999))
                 path.moveTo(newPath)
             except OSError, e:
                 print ("could not rename path, caught OSError [Errno %s]: %s"
-                       % (e.errno,e.strerror))
+                       % (e.errno, e.strerror))
                 raise
 
 
